# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class S3BlobStoreApiBucketSecurity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_key_id': 'str',
        'secret_access_key': 'str',
        'role': 'str',
        'session_token': 'str'
    }

    attribute_map = {
        'access_key_id': 'accessKeyId',
        'secret_access_key': 'secretAccessKey',
        'role': 'role',
        'session_token': 'sessionToken'
    }

    def __init__(self, access_key_id=None, secret_access_key=None, role=None, session_token=None, local_vars_configuration=None):  # noqa: E501
        """S3BlobStoreApiBucketSecurity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_key_id = None
        self._secret_access_key = None
        self._role = None
        self._session_token = None
        self.discriminator = None

        if access_key_id is not None:
            self.access_key_id = access_key_id
        if secret_access_key is not None:
            self.secret_access_key = secret_access_key
        if role is not None:
            self.role = role
        if session_token is not None:
            self.session_token = session_token

    @property
    def access_key_id(self):
        """Gets the access_key_id of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        An IAM access key ID for granting access to the S3 bucket  # noqa: E501

        :return: The access_key_id of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._access_key_id

    @access_key_id.setter
    def access_key_id(self, access_key_id):
        """Sets the access_key_id of this S3BlobStoreApiBucketSecurity.

        An IAM access key ID for granting access to the S3 bucket  # noqa: E501

        :param access_key_id: The access_key_id of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._access_key_id = access_key_id

    @property
    def secret_access_key(self):
        """Gets the secret_access_key of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        The secret access key associated with the specified IAM access key ID  # noqa: E501

        :return: The secret_access_key of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._secret_access_key

    @secret_access_key.setter
    def secret_access_key(self, secret_access_key):
        """Sets the secret_access_key of this S3BlobStoreApiBucketSecurity.

        The secret access key associated with the specified IAM access key ID  # noqa: E501

        :param secret_access_key: The secret_access_key of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._secret_access_key = secret_access_key

    @property
    def role(self):
        """Gets the role of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        An IAM role to assume in order to access the S3 bucket  # noqa: E501

        :return: The role of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this S3BlobStoreApiBucketSecurity.

        An IAM role to assume in order to access the S3 bucket  # noqa: E501

        :param role: The role of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def session_token(self):
        """Gets the session_token of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        An AWS STS session token associated with temporary security credentials which grant access to the S3 bucket  # noqa: E501

        :return: The session_token of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._session_token

    @session_token.setter
    def session_token(self, session_token):
        """Sets the session_token of this S3BlobStoreApiBucketSecurity.

        An AWS STS session token associated with temporary security credentials which grant access to the S3 bucket  # noqa: E501

        :param session_token: The session_token of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._session_token = session_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3BlobStoreApiBucketSecurity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3BlobStoreApiBucketSecurity):
            return True

        return self.to_dict() != other.to_dict()
